.. :changelog:

History
-------

1.1.0 (2019-10-18)
---------------------

* Support up to Python 3.8, drop explicit support for 2.6/3.2/3.3
* Raise TypeError on invalid addition/subtraction instead of ValueError

1.0.0 (2015-04-13)
---------------------

* Documentation added
* 2.6 support added
* Tests for bad math added

0.1.0 (2015-04-13)
---------------------

* First release on PyPI.
